@@ -681,7 +681,7 @@ void Tray::slotUpdateDeviceState()
 	// FIXME
 }
 
-void Tray::slotUpdateDeviceState(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TDENetworkConnectionStatus::TDENetworkConnectionStatus prevState, TQString hwAddress)
+void Tray::slotUpdateDeviceState(TDENetworkConnectionStatus::TDENetworkConnectionStatus newState, TDENetworkConnectionStatus::TDENetworkConnectionStatus prevState, TQString deviceNode)
 {
 #ifdef DEBUG_STATE
 	printf("Device state: 0x%08x was: 0x%08x\n", newState, prevState);
